Struct Row

pub struct Row<'mmap> { /* private fields */ }

Implementations

Source

impl<'mmap> Row<'mmap>

pub fn new( slice: &'mmap [u8], field_separator: u8, string_delimiter: u8, force_mem_cacher: bool, ) -> Self

Constructor
  • Make a new instance of Row struct.
pub fn new_empty() -> Self

Creates a new Empty row
pub fn is_empty(&self) -> bool

Is Empty
  • Gets if a row is empty
pub fn get_slice(&self) -> &'mmap [u8]

Get Slice of &[u8] bytes
  • Gets a reference of the bytes inside row.
returns : &’mmap [u8]
pub fn next_field(&mut self) -> Option<Field<'mmap>>

Next Field
  • Finds the next slice between current position and delimiter
  • Pack this slice, inside a Field struct in order to access field functions.
  • Can iter between differents Fields, in order.
returns : An Option<Field<’mmap>>
pub fn get_index(&mut self, index: usize) -> Field<'mmap>

Get Field by Index
  • Receives an usize (zero based index), and returns the field associated to the iteration.
returns: An Option<Field<’mmap>>
pub fn decode_line(&mut self, enc: Encoding) -> Cow<'_, str>

Decodes the full line
  • Must give the encoding.